@@ -34,6 +34,6 @@ EXTRACTOR_FILENAME = os.path.join(DATA_DIR, 'classifier')
 EXTRACTOR_DATA = os.path.join(DATA_DIR, 'train.data')
 
 
-#def initialize():
-extraction.EXTRACTOR = classifier.load(EXTRACTOR_FILENAME,
+def initialize():
+    extraction.EXTRACTOR = classifier.load(EXTRACTOR_FILENAME,
                                            EXTRACTOR_DATA)
